@@ -1,12 +1,24 @@
 /* **********************************************************
  * Copyright (C) 1998-2000 VMware, Inc.
  * All Rights Reserved
- * $Id: x86.h,v 1.5 2003/02/16 15:32:34 bad Exp $
+ * $Id: x86.h,v 1.6 2003/03/16 18:11:30 jdolecek Exp $
  * **********************************************************/
 
 #ifndef _X86_H_
 #define _X86_H_
 
+#ifdef __NetBSD__
+#include <sys/param.h>		/* for __NetBSD_Version__ */
+#include <i386/specialreg.h>	/* for MSR_* */
+
+# if __NetBSD_Version__ > 105009900
+#  include <uvm/uvm_extern.h>
+# else
+#  include <vm/vm.h>
+# endif
+
+#endif
+
 #define INCLUDE_ALLOW_USERLEVEL
 #define INCLUDE_ALLOW_MONITOR
 #define INCLUDE_ALLOW_MODULE
@@ -285,17 +297,18 @@ OpsizeValue(uint32 value,	// IN: The 32 bit value to be sized.
 
 #define CPUID_EXTENDED_MODEL(_eax)    (((_eax) >> 16) & 0xf)
 
+#define MSR_L2CFG            0x0000011e
+#if !defined(__NetBSD__) || (__NetBSD_Version__ < 106120000)
 #define MSR_TSC              0x00000010
 #define MSR_PERFCTR0         0x000000c1
 #define MSR_PERFCTR1         0x000000c2
 #define MSR_MTRR_CAP         0x000000fe
-#define MSR_L2CFG            0x0000011e
 #define MSR_SYSENTER_CS      0x00000174
 #define MSR_SYSENTER_ESP     0x00000175
 #define MSR_SYSENTER_EIP     0x00000176
 #define MSR_EVNTSEL0         0x00000186
 #define MSR_EVNTSEL1         0x00000187
-
+#endif /* __NetBSD_Version__ < 106120000 */
 
 typedef uint32 CReg;
 
